#!/bin/bash

# installing a Cool VL Viewer
# by merging the contests of a LL Snowglobe
# with the files in our deplay archive

# some functions
x() {
  # usage: x string num
  for (( i=1; i<=$2; i++ )) do printf "%s" "$1"; done
  # print a newline only if the string does not end in a newline
  [[ "$1" == "${1%$'\n'}" ]] && echo ""
}

# config
me=${2:-$(basename "$0" ".sh")}
execdir=`dirname $0`

# output friendly message to user ^^
msg="Welcome to the $me installer"
echo
x '*' ${#msg}
echo $msg
x '*' ${#msg}
echo

echo "working in $execdir"
resdir="$execdir/../Resources"
if test -d "$resdir" # we are inside an app bundle
	then topdir="$execdir/../../.."
	else # we are called feom a dir
		topdir="$PWD"; # assume files are in the dir we were called from
		resdir=$topdir
fi
echo "Top dir is: $topdir\nResource dir is: $resdir"

# First, find out deployment archive
# from it's name we can construct the app name later
echo "checking for deployment archive"
# try $resdir first
echo "checking in $resdir"
archivepath=`ls $resdir/*deploy.zip 2>/dev/null` # don't care for error
if [ "$archivepath" = "" ] 
	# try the topdir too
	then echo "ERROR: no deploy archive in $resdir"
	echo "checking in $topdir"
	archivepath=`ls $topdir/*deploy.zip 2>/dev/null`
	if [ "$archivepath" = "" ] 
		then echo "ERROR: no deploy archive in $topdir"
		exit 1
	fi
fi

# get the name from the path
echo
echo "finding name of Application to create"
# echo "path to archive: '$archivepath'"
archivename=`basename $archivepath`
echo "archive name is: $archivename"
appname=`echo $archivename|cut -d'.' -f1`
echo "Application name is: $appname"
echo

# find or obtain the Snowglobe DMG
dmg=Snowglobe_1_4_2_3626.dmg
dmgpath="$topdir/$dmg"
dlurl=http://secondlife.com/developers/opensource/downloads/2009/1.4/3626/$dmg

msg="get the Snowglobe DMG (if we don't already have it)"
echo $msg
x '*' ${#msg}

if test -f $dmgpath 
	then 
		echo "we have it in $dmgpath"
	else
		echo "need to download it from LL servers (only need to do this once)"
		curl -L -o "$dmgpath" $dlurl
fi
echo

echo "creating empty app $topdir/$appname.app"
mkdir -v "$topdir/$appname.app"

# and then copy over everything that is in $appname.deploy.zip
# this will merge the deployed Cool VL files with the Snowglobe ones,
# overwriting any Snowglobe ones that Cool VL has to change
echo
echo "creating full Cool VL Viewer app"
ditto -xkv $archivepath "$topdir/$appname.app"
echo 

echo "Adding snowglobe components"

echo "mounting the Snowglobe DMG"
hdiutil attach "$dmgpath"
# see if it was mounted and find it's real name
volname=`ls /Volumes/ |grep -i snowglobe`
if [ "$volname" = "" ] 
	then echo "Snowglobe DMG wasn't mounted! Quitting now.";
	exit 1;
fi
# build full path
volume=/Volumes/$volname
echo
echo "Snowglobe DMG was mounted as $volume"

# copy out the .app file
echo "Copying KDU and Voice Components"
cp "$volume/Snowglobe.app/Contents/Resources/SLVoice" "$topdir/$appname.app/Contents/Resources"
cp "$volume/Snowglobe.app/Contents/Resources/libvivoxsdk.dylib" "$topdir/$appname.app/Contents/Resources"
cp "$volume/Snowglobe.app/Contents/Resources/libllkdu.dylib" "$topdir/$appname.app/Contents/Resources"
cp "$volume/Snowglobe.app/Contents/Resources/libortp.dylib" "$topdir/$appname.app/Contents/Resources"
cp "$volume/Snowglobe.app/Contents/Resources/libalut.dylib" "$topdir/$appname.app/Contents/Resources"

echo "done."
echo "unmounting the DMG again"
hdiutil detach "$volume"
echo

# possibly move/copy the reaulte into /Applications folder
# dome!
msg="DONE, you can now copy $appname.app anywhere you want (/Applications/ is a good choice)"
x '*' ${#msg}
echo $msg
echo "You can now safely close this Terminal window"
open -R "$topdir/$appname.app"
